
# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell
#
# dephell deps convert --from-format=poetry --from-path=pyproject.toml --to-format=setuppy --to-path=debian/setup.py


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


import os.path

readme = ''
here = os.path.abspath(os.path.dirname(__file__))
readme_path = os.path.join(here, 'README.rst')
if os.path.exists(readme_path):
    with open(readme_path, 'rb') as stream:
        readme = stream.read().decode('utf8')


setup(
    long_description=readme,
    name='rich',
    version='8.0.0',
    description='Render rich text, tables, progress bars, syntax highlighting, markdown and more to the terminal',
    python_requires='==3.*,>=3.6.0',
    project_urls={"documentation": "https://rich.readthedocs.io/en/latest/", "homepage": "https://github.com/willmcgugan/rich"},
    author='Will McGugan',
    author_email='willmcgugan@gmail.com',
    license='MIT',
    classifiers=['Development Status :: 5 - Production/Stable', 'Environment :: Console', 'Intended Audience :: Developers', 'Operating System :: Microsoft :: Windows', 'Operating System :: MacOS', 'Operating System :: POSIX :: Linux', 'Programming Language :: Python :: 3.6', 'Programming Language :: Python :: 3.7', 'Programming Language :: Python :: 3.8'],
    packages=['rich'],
    package_dir={"": "."},
    package_data={"rich": ["*.typed"]},
    install_requires=['colorama==0.*,>=0.4.0', 'commonmark==0.*,>=0.9.0', 'dataclasses==0.*,>=0.7.0; python_version == "3.6.*" and python_version >= "3.6.0"', 'pygments==2.*,>=2.6.0', 'typing-extensions==3.*,>=3.7.4'],
    extras_require={"jupyter": ["ipywidgets==7.*,>=7.5.1"]},
)
